@@ -24,10 +24,6 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <gnome.h>
-#include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-utils.h>
@@ -48,7 +44,8 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 						gchar **program_args,
 						gboolean *run_in_terminal)
 {
-	GladeXML *gxml;
+	GError* error = NULL;
+	GtkBuilder *bxml;
 	GtkWidget *dlg, *treeview, *use_terminal_check, *arguments_entry;
 	GtkWidget *treeview_frame;
 	GtkTreeViewColumn *column;
@@ -81,13 +78,18 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 	{
 		exec_targets = NULL;
 	}
-		
-	gxml = glade_xml_new (GLADE_FILE, "execute_dialog", NULL);
-	dlg = glade_xml_get_widget (gxml, "execute_dialog");
-	treeview = glade_xml_get_widget (gxml, "programs_treeview");
-	treeview_frame = glade_xml_get_widget (gxml, "treeview_frame");
-	use_terminal_check = glade_xml_get_widget (gxml, "program_run_in_terminal");
-	arguments_entry = glade_xml_get_widget (gxml, "program_arguments");
+
+	bxml = gtk_builder_new();
+	if (!gtk_builder_add_from_file (bxml, BUILDER_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}		
+	dlg = GTK_WIDGET (gtk_builder_get_object (bxml, "execute_dialog"));
+	treeview = GTK_WIDGET (gtk_builder_get_object (bxml, "programs_treeview"));
+	treeview_frame = GTK_WIDGET (gtk_builder_get_object (bxml, "treeview_frame"));
+	use_terminal_check = GTK_WIDGET (gtk_builder_get_object (bxml, "program_run_in_terminal"));
+	arguments_entry = GTK_WIDGET (gtk_builder_get_object (bxml, "program_arguments"));
 	
 	gtk_window_set_transient_for (GTK_WINDOW (dlg),
 								  GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell));
@@ -114,7 +116,7 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 			gchar *local_path;
 			const gchar *rel_path;
 		
-			local_path = gnome_vfs_get_local_path_from_uri ((gchar*)node->data);
+			local_path = anjuta_util_get_local_path_from_uri ((gchar *)node->data);
 			if (local_path == NULL)
 			{
 				g_free (node->data);
@@ -212,7 +214,7 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 		}
 	}
 	gtk_widget_destroy (dlg);
-	g_object_unref (gxml);
+	g_object_unref (bxml);
 	return success;
 }
 
@@ -287,7 +289,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 		/* Check if target is local */
 		gchar *local_uri;
 		
-		local_uri = gnome_vfs_get_local_path_from_uri (target);
+		local_uri = anjuta_util_get_local_path_from_uri (target);
 		if (local_uri == NULL)
 		{
 			error_condition = TRUE;
@@ -332,7 +334,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 		anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell, "current_editor",
 						  G_TYPE_OBJECT, &te, NULL);
 		
-		filename = gnome_vfs_get_local_path_from_uri (target);
+		filename = anjuta_util_get_local_path_from_uri (target);
 		prog = NULL;
 		prog = g_strdup (filename);
 		temp = g_strrstr (prog, ".");
@@ -372,7 +374,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 	else
 		cmd = g_strdup (target);
 
-	if (anjuta_preferences_get_int (prefs , PREF_USE_SB))
+	if (anjuta_preferences_get_bool (prefs , PREF_USE_SB))
 	{
 		const gchar* sb_path = anjuta_preferences_get(prefs, PREF_SB_PATH);
 		/* we need to skip the /scratchbox/users part, maybe could be done more clever */
@@ -417,7 +419,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 				}
 				else
 				{
-					DEBUG_PRINT("Missing anjuta_launcher");
+					DEBUG_PRINT("%s", "Missing anjuta_launcher");
 				}
 				
 			}
@@ -426,13 +428,12 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 		}
 		else
 		{
-			DEBUG_PRINT ("No installed terminal plugin found");
-			gnome_execute_shell (dir, cmd);
+			anjuta_util_execute_shell (dir, cmd);
 		}
 	}
 	else
 	{
-		gnome_execute_shell (dir, cmd);
+		anjuta_util_execute_shell (dir, cmd);
 	}
 	
 	g_free (dir);
