@@ -32,7 +32,6 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <gnome.h>
 #include "disassemble.h"
 
 #include "sparse_buffer.h"
@@ -802,7 +801,7 @@ on_program_moved (DmaDisassemble *self, guint pid, guint tid, gulong address, co
 }
 
 static void
-on_location_changed (DmaDisassemble *self, gulong address, const gchar* uri, guint line)
+on_location_changed (DmaDisassemble *self, gulong address, GFile* file, guint line)
 {
 	dma_sparse_view_goto (self->view, address);
 }
@@ -850,7 +849,7 @@ create_disassemble_gui (DmaDisassemble *self)
 	anjuta_shell_add_widget (ANJUTA_PLUGIN (self->plugin)->shell,
 							 self->window,
                              "AnjutaDebuggerDisassemble", _("Disassembly"),
-                             NULL, ANJUTA_SHELL_PLACEMENT_LEFT,
+                             NULL, ANJUTA_SHELL_PLACEMENT_NONE,
 							 NULL);
 
 	return TRUE;
