@@ -38,6 +38,7 @@
 #include "queue.h"
 #include "variable.h"
 
+#include <glib/gi18n.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-status.h>
@@ -50,14 +51,14 @@
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
 
 /* Contants defintion
  *---------------------------------------------------------------------------*/
 
 #define ICON_FILE "anjuta-debug-manager-plugin-48.png"
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-debug-manager.ui"
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-debug-manager.glade"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-debug-manager.xml"
+#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-debug-manager.ui"
 
 /* Plugin type
  *---------------------------------------------------------------------------*/
@@ -396,15 +397,6 @@ dma_plugin_program_loaded (DebugManagerPlugin *this)
 
 	DEBUG_PRINT ("%s", "DMA: dma_plugin_program_loaded");
 	
-	if (this->sharedlibs == NULL)
-	{
-		this->sharedlibs = sharedlibs_new (this);
-	}
-	if (this->signals == NULL)
-	{
-		this->signals = signals_new (this);
-	}
-
 	/* Update ui */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	gtk_action_group_set_sensitive (this->loaded_group, TRUE);
@@ -476,17 +468,6 @@ dma_plugin_program_unload (DebugManagerPlugin *this)
 
 	DEBUG_PRINT ("%s", "DMA: dma_plugin_program_unload");
 	
-	if (this->sharedlibs != NULL)
-	{
-		sharedlibs_free (this->sharedlibs);
-		this->sharedlibs = NULL;
-	}
-	if (this->signals == NULL)
-	{
-		signals_free (this->signals);
-		this->signals = NULL;
-	}
-
 	/* Update ui */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	gtk_action_group_set_visible (this->start_group, TRUE);
@@ -725,12 +706,17 @@ on_debugger_command_entry_activate (GtkEntry *entry, DebugManagerPlugin *plugin)
 static void
 on_debugger_custom_command_activate (GtkAction * action, DebugManagerPlugin *plugin)
 {
-        GladeXML *gxml;
+        GtkBuilder *bxml = gtk_builder_new ();
         GtkWidget *win, *entry;
+		GError* error = NULL;
 
-        gxml = glade_xml_new (GLADE_FILE, "debugger_command_dialog", NULL);
-        win = glade_xml_get_widget (gxml, "debugger_command_dialog");
-        entry = glade_xml_get_widget (gxml, "debugger_command_entry");
+		if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
+		{
+			g_warning ("Couldn't load builder file: %s", error->message);
+			g_error_free (error);
+		}
+        win = GTK_WIDGET (gtk_builder_get_object (bxml, "debugger_command_dialog"));
+        entry = GTK_WIDGET (gtk_builder_get_object (bxml, "debugger_command_entry"));
 
         gtk_window_set_transient_for (GTK_WINDOW (win),
                                                                   GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell));
@@ -740,7 +726,7 @@ on_debugger_custom_command_activate (GtkAction * action, DebugManagerPlugin *plu
         g_signal_connect (entry, "activate",
                                           G_CALLBACK (on_debugger_command_entry_activate),
                                           plugin);
-        g_object_unref (gxml);
+        g_object_unref (bxml);
 }
 
 /* Info callbacks
@@ -1068,9 +1054,8 @@ static gboolean
 dma_plugin_activate (AnjutaPlugin* plugin)
 {
 	DebugManagerPlugin *this;
-    static gboolean initialized = FALSE;
+	static gboolean initialized = FALSE;
 	AnjutaUI *ui;
-	GtkAction *action;
 	
 	DEBUG_PRINT ("%s", "DebugManagerPlugin: Activating Debug Manager plugin...");
 	this = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
@@ -1144,7 +1129,13 @@ dma_plugin_activate (AnjutaPlugin* plugin)
 
 	/* Start debugger part */
 	this->start = dma_start_new (this);
-	
+
+	/* Shared libraries part */
+	this->sharedlibs = sharedlibs_new (this);
+
+	/* Signal part */
+	this->signals = signals_new (this);
+
 	dma_plugin_debugger_stopped (this, 0);
 	
 	/* Add watches */
@@ -1213,6 +1204,12 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	dma_start_free (this->start);
 	this->start = NULL;
 
+	sharedlibs_free (this->sharedlibs);
+	this->sharedlibs = NULL;
+
+	signals_free (this->signals);
+	this->signals = NULL;
+
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	anjuta_ui_remove_action_group (ui, this->start_group);
 	anjuta_ui_remove_action_group (ui, this->loaded_group);
