@@ -50,8 +50,8 @@
 #include "search-box.h"
 #include "anjuta-bookmarks.h"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-document-manager.ui"
-#define PREFS_GLADE PACKAGE_DATA_DIR"/glade/anjuta-document-manager.glade"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-document-manager.xml"
+#define PREFS_BUILDER PACKAGE_DATA_DIR"/glade/anjuta-document-manager.ui"
 #define ICON_FILE "anjuta-document-manager-plugin-48.png"
 
 #define ANJUTA_PIXMAP_BOOKMARK_TOGGLE     "anjuta-bookmark-toggle"
@@ -492,7 +492,7 @@ update_title (DocmanPlugin* doc_plugin)
 			if (dir)
 				title = g_strdup_printf ("%s (%s)", real_filename, dir);
 			else
-				title = g_strdup_printf ("%s", real_filename);
+				title = g_strdup_printf ("%s (%s)", real_filename, dir);				
 		}
 		g_free (real_filename);
 		g_free (dir);
@@ -577,7 +577,7 @@ ui_states_init (AnjutaPlugin *plugin)
 		GtkAction *action;
 		gboolean state;
 		
-		state = anjuta_preferences_get_int (eplugin->prefs, prefs[i]);
+		state = anjuta_preferences_get_bool (eplugin->prefs, prefs[i]);
 		action = anjuta_ui_get_action (eplugin->ui, "ActionGroupEditorView",
 									   actions_view[i].name);
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), state);
@@ -1326,7 +1326,7 @@ on_window_key_release_event (AnjutaShell *shell,
 		gint cur_page;
 		plugin->g_tabbing = FALSE;
 		
-		if (anjuta_preferences_get_int (plugin->prefs,
+		if (anjuta_preferences_get_bool (plugin->prefs,
 										EDITOR_TABS_RECENT_FIRST))
 		{
 			/*
@@ -1450,8 +1450,8 @@ on_save_prompt (AnjutaShell *shell, AnjutaSavePrompt *save_prompt,
 static void
 docman_plugin_set_tab_pos (DocmanPlugin *ep)
 {
-	if (anjuta_preferences_get_int_with_default (ep->prefs, EDITOR_TABS_HIDE,
-												 1))
+	if (anjuta_preferences_get_bool_with_default (ep->prefs, EDITOR_TABS_HIDE,
+												 TRUE))
 	{
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (ep->docman), FALSE);
 	}
@@ -1481,8 +1481,8 @@ docman_plugin_set_tab_pos (DocmanPlugin *ep)
 }
 
 static void
-on_gconf_notify_prefs (GConfClient *gclient, guint cnxn_id,
-					   GConfEntry *entry, gpointer user_data)
+on_notify_prefs (AnjutaPreferences* prefs, 
+                 const gchar* key, gint value, gpointer user_data)
 {
 	DocmanPlugin *ep = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman_plugin_set_tab_pos (ep);
@@ -1505,7 +1505,7 @@ on_docman_auto_save (gpointer data)
 		return FALSE;
 
 	prefs = anjuta_shell_get_preferences (docman->shell, NULL);
-	if (anjuta_preferences_get_int (prefs, SAVE_AUTOMATIC) == FALSE)
+	if (anjuta_preferences_get_bool (prefs, SAVE_AUTOMATIC) == FALSE)
 	{
 		plugin->autosave_on = FALSE;
 		return FALSE;
@@ -1554,22 +1554,21 @@ on_docman_auto_save (gpointer data)
 }
 
 static void
-on_gconf_notify_timer (GConfClient *gclient, guint cnxn_id,
-					   GConfEntry *entry, gpointer user_data)
+on_notify_timer (AnjutaPreferences* prefs,
+                 const gchar* key,
+                 gboolean value,
+                 gpointer user_data)
 {
 	DocmanPlugin *plugin;
 	AnjutaDocman *docman;
-	AnjutaPreferences* prefs;
 	gint auto_save_timer;
 	gboolean auto_save;
 	
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
-
-	prefs = anjuta_shell_get_preferences (docman->shell, NULL);
 	
 	auto_save_timer = anjuta_preferences_get_int(prefs, AUTOSAVE_TIMER);
-	auto_save = anjuta_preferences_get_int(prefs, SAVE_AUTOMATIC);
+	auto_save = anjuta_preferences_get_bool(prefs, SAVE_AUTOMATIC);
 	
 	if (auto_save)
 	{
@@ -1599,8 +1598,8 @@ on_gconf_notify_timer (GConfClient *gclient, guint cnxn_id,
 	}
 }
 
-#define REGISTER_NOTIFY(key, func) \
-	notify_id = anjuta_preferences_notify_add (ep->prefs, \
+#define REGISTER_NOTIFY(key, func, type) \
+	notify_id = anjuta_preferences_notify_add_##type (ep->prefs, \
 											   key, func, ep, NULL); \
 	ep->gconf_notify_ids = g_list_prepend (ep->gconf_notify_ids, \
 										   GUINT_TO_POINTER (notify_id));
@@ -1609,12 +1608,12 @@ prefs_init (DocmanPlugin *ep)
 {
 	guint notify_id;
 	docman_plugin_set_tab_pos (ep);
-	REGISTER_NOTIFY (EDITOR_TABS_HIDE, on_gconf_notify_prefs);
-	REGISTER_NOTIFY (EDITOR_TABS_POS, on_gconf_notify_prefs);
-	REGISTER_NOTIFY (AUTOSAVE_TIMER, on_gconf_notify_timer);
-	REGISTER_NOTIFY (SAVE_AUTOMATIC, on_gconf_notify_timer);
+	REGISTER_NOTIFY (EDITOR_TABS_HIDE, on_notify_prefs, bool);
+	REGISTER_NOTIFY (EDITOR_TABS_POS, on_notify_prefs, int);
+	REGISTER_NOTIFY (AUTOSAVE_TIMER, on_notify_timer, bool);
+	REGISTER_NOTIFY (SAVE_AUTOMATIC, on_notify_timer, bool);
 	
-	on_gconf_notify_timer(NULL,0,NULL, ep);
+	on_notify_timer(anjuta_preferences_default(), NULL, FALSE, ep);
 }
 
 static void
@@ -1709,7 +1708,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	dplugin->uiid = anjuta_ui_merge (ui, UI_FILE);
 	dplugin->vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (dplugin->vbox);
-	gtk_box_pack_start_defaults (GTK_BOX(dplugin->vbox), docman);
+	gtk_box_pack_start (GTK_BOX(dplugin->vbox), docman, TRUE, TRUE, 0);
 	anjuta_shell_add_widget_full (plugin->shell, dplugin->vbox,
 							 "AnjutaDocumentManager", _("Documents"),
 							 "editor-plugin-icon", 
@@ -2117,15 +2116,20 @@ isavable_iface_init (IAnjutaFileSavableIface *iface)
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
-	GladeXML* gxml;
+	GError* error = NULL;
+	GtkBuilder* bxml = gtk_builder_new ();
 	
 	/* Add preferences */
-	gxml = glade_xml_new (PREFS_GLADE, "preferences_dialog", NULL);
-		
-	anjuta_preferences_add_page (prefs,
-									gxml, "Documents", _("Documents"),  ICON_FILE);
-				
-	g_object_unref (G_OBJECT (gxml));
+	if (!gtk_builder_add_from_file (bxml, PREFS_BUILDER, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+
+	anjuta_preferences_add_from_builder (prefs,
+									bxml, "Documents", _("Documents"),  ICON_FILE);
+
+	g_object_unref (G_OBJECT (bxml));
 }
 
 static void
