@@ -22,7 +22,7 @@
 
 /* For testing propose use the local (not installed) glade file */
 /* #define GLADE_FILE PACKAGE_DATA_DIR"/[+NameHLower+]/glade/[+NameHLower+].glade" */
-#define GLADE_FILE "[+NameHLower+].glade"
+#define GLADE_FILE "src/[+NameHLower+].glade"
    
 int
 main (int argc, char *argv[])
