@@ -411,7 +411,7 @@ run_program (RunProgramPlugin *plugin)
 
 	/* Take care of scratchbox */
 	prefs = anjuta_shell_get_preferences (ANJUTA_PLUGIN(plugin)->shell, NULL);
-	if (anjuta_preferences_get_int (prefs , PREF_USE_SB))
+	if (anjuta_preferences_get_bool (prefs , PREF_USE_SB))
 	{
 		const gchar* sb_path = anjuta_preferences_get(prefs, PREF_SB_PATH);
 		/* we need to skip the /scratchbox/users part, maybe could be done more clever */
