@@ -21,8 +21,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <gnome.h>
-#include <glade/glade.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-plugin.h>
@@ -41,9 +41,9 @@
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <glib/gi18n.h>
 
-#define GLADE_FILE_SEARCH_REPLACE PACKAGE_DATA_DIR"/glade/anjuta-search.glade"
+#define BUILDER_FILE_SEARCH_REPLACE PACKAGE_DATA_DIR"/glade/anjuta-search.ui"
 
-/* LibGlade's auto-signal-connect will connect to these signals.
+/* GtkBuilder's auto-signal-connect will connect to these signals.
  * Do not declare them static.
  */
 gboolean
@@ -118,7 +118,7 @@ AnjutaUtilStringMap search_action_strings[] = {
 
 typedef struct _SearchReplaceGUI
 {
-	GladeXML *xml;
+	GtkBuilder *bxml;
 	GtkWidget *dialog;
 	gboolean showing;
 } SearchReplaceGUI;
@@ -283,9 +283,9 @@ search_and_replace (void)
 	FileBuffer *fb;
 	static MatchInfo *mi;
 	Search *s;
-	gint offset;
+	gint offset;			/* offset due to previous replace */
 	gint found_line = 0;
-	static gint os = 0;
+	static gint os = 0;		/* Keep previous offset when doing interactibe S&R */
 	gint nb_results;
 	static long start_sel = 0;
 	static long end_sel = 0;
@@ -368,7 +368,7 @@ search_and_replace (void)
 				se->start_pos = g_utf8_strlen (fb->buf, start_sel);
 				se->end_pos = g_utf8_strlen (fb->buf, end_sel);
 			}
-			else
+			else if (se->end_pos != -1)
 			 {
 				end_sel = g_utf8_offset_to_pointer (fb->buf, se->end_pos) - fb->buf;
 			 }
@@ -382,10 +382,10 @@ search_and_replace (void)
 			while (interactive || 
 				NULL != (mi = get_next_match(fb, s->range.direction, &(s->expr))))
 			{
-				if ((s->range.direction == SD_BACKWARD) && (mi->pos < se->end_pos))
+				if ((s->range.direction == SD_BACKWARD) && (mi->pos < end_sel))
 						break; 
-				if ((s->range.direction != SD_BACKWARD) && ((se->end_pos != -1) &&
-					(mi->pos+mi->len > se->end_pos)))
+				if ((s->range.direction != SD_BACKWARD) && ((end_sel != 0) &&
+					(mi->pos+mi->len > end_sel)))
 						break; 
 				nb_results++; 
 				if (nb_results > sr->search.expr.actions_max)
@@ -406,14 +406,14 @@ search_and_replace (void)
 
 						if (IANJUTA_INDICABLE (fb->te))
 						{
-							gint offset;
+							gint char_pos;
 							IAnjutaIterable *start_pos, *end_pos;
 							/* end-location is correct for sourceview, 1-too-big for scintilla */
 
-							offset = g_utf8_strlen (fb->buf, mi->pos);
-							start_pos = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
-							offset += g_utf8_strlen (fb->buf + mi->pos, mi->len);
-							end_pos = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
+							char_pos = g_utf8_strlen (fb->buf, mi->pos);
+							start_pos = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos, mi->len);
+							end_pos = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_indicable_set (IANJUTA_INDICABLE(fb->te),
 												   start_pos, end_pos,
 												   IANJUTA_INDICABLE_IMPORTANT, NULL);
@@ -446,13 +446,13 @@ search_and_replace (void)
 							found_line = mi->line;
 						}
 						{
-							gint offset;
+							gint char_pos;
 							IAnjutaIterable *start, *end;
 
-							offset = g_utf8_strlen (fb->buf, mi->pos);
-							start = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
-							offset += g_utf8_strlen (fb->buf + mi->pos, mi->len);
-							end = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
+							char_pos = g_utf8_strlen (fb->buf, mi->pos);
+							start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos, mi->len);
+							end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
@@ -469,7 +469,7 @@ search_and_replace (void)
 					
 					case SA_REPLACE:
 						if (found_line != mi->line || fb->te == NULL)
-							{
+						{
 							if (fb->te)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
@@ -478,17 +478,17 @@ search_and_replace (void)
 									(sr->docman, fb->file, mi->line, FALSE, NULL);
 							}
 							found_line = mi->line;
-							}
+						}
 
 						if (!interactive)
 						{
-							gint offset;
+							gint char_pos;
 							IAnjutaIterable *start, *end;
 
-							offset = g_utf8_strlen (fb->buf, mi->pos);
-							start = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
-							offset += g_utf8_strlen (fb->buf + mi->pos, mi->len);
-							end = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
+							char_pos = g_utf8_strlen (fb->buf, mi->pos - offset);
+							start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos - offset, mi->len);
+							end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
@@ -505,25 +505,25 @@ search_and_replace (void)
 							{
 									g_free (ch);
 								ch = regex_backref (mi, fb);
-								}
 							}
+						}
 						else
 						{
-						if (ch && sr->replace.regex && sr->search.expr.regex)
-						{
+							if (ch && sr->replace.regex && sr->search.expr.regex)
+							{
 								g_free (sr->replace.repl_str);
 								sr->replace.repl_str = g_strdup (ch);
-							g_free (ch);
+								g_free (ch);
 								ch = NULL;
-						}
+							}
 							{
-								gint offset;
+								gint char_pos;
 								IAnjutaIterable *start, *end;
 
-								offset = g_utf8_strlen (fb->buf, mi->pos);
-								start = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
-								offset += g_utf8_strlen (fb->buf + mi->pos, mi->len);
-								end = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
+								char_pos = g_utf8_strlen (fb->buf, mi->pos - os);
+								start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+								char_pos += g_utf8_strlen (fb->buf + mi->pos - os, mi->len);
+								end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 								ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 															 start,														 
 															 end,
@@ -536,10 +536,10 @@ search_and_replace (void)
 								g_object_unref (start);
 								g_object_unref (end);
 							}
-						if (se->direction != SD_BACKWARD)
-							offset += mi->len - (sr->replace.repl_str?strlen(sr->replace.repl_str):0);
+							if (se->direction != SD_BACKWARD)
+								offset += mi->len - (sr->replace.repl_str?strlen(sr->replace.repl_str):0);
 						
-						interactive = FALSE;
+							interactive = FALSE;
 						}
 						break;
 
@@ -558,13 +558,13 @@ search_and_replace (void)
 						}
 						else
 						{
-							gint offset;
+							gint char_pos;
 							IAnjutaIterable *start, *end;
 
-							offset = g_utf8_strlen (fb->buf, mi->pos);
-							start = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
-							offset += g_utf8_strlen (fb->buf + mi->pos, mi->len);
-							end = ianjuta_editor_get_position_from_offset (fb->te, offset, NULL);
+							char_pos = g_utf8_strlen (fb->buf, mi->pos - offset);
+							start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos - offset, mi->len);
+							end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 														 start,
 														 end,
@@ -654,9 +654,7 @@ write_message_pane(IAnjutaMessageView* view, FileBuffer *fb, SearchEntry *se,
 	int line = mi->line;
 	gchar *buf;
 	gchar *path = NULL;
-	
-	if (se->type == SE_FILE)
-		++line;
+
 	if (fb->file != NULL)
 	{
 		gchar *dir_uri = NULL;	
@@ -736,7 +734,6 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 			g_free(path);
 		}
 		g_free(project_path);
-		g_free(project_uri);
 	}
 	if (!real_path)
 		real_path = path;
@@ -1279,6 +1276,7 @@ void translate_dialog_strings (AnjutaUtilStringMap labels[])
 static gboolean
 create_dialog(void)
 {
+	GError* error = NULL;
 	GladeWidget *w;
 	GtkWidget *widget;
 	int i;
@@ -1287,15 +1285,17 @@ create_dialog(void)
 	if (NULL != sg) return TRUE;
 	sg = g_new0(SearchReplaceGUI, 1);
 
-	if (NULL == (sg->xml = glade_xml_new(GLADE_FILE_SEARCH_REPLACE,
-		SEARCH_REPLACE_DIALOG, NULL)))
+	sg->bxml = gtk_builder_new ();
+	if (!gtk_builder_add_from_file (sg->bxml, BUILDER_FILE_SEARCH_REPLACE, &error))
 	{
 		anjuta_util_dialog_error(NULL, _("Unable to build user interface for Search And Replace"));
 		g_free(sg);
 		sg = NULL;
+		g_error_free (error);
 		return FALSE;
 	}
-	sg->dialog = glade_xml_get_widget(sg->xml, SEARCH_REPLACE_DIALOG);
+
+	sg->dialog = GTK_WIDGET (gtk_builder_get_object (sg->bxml, SEARCH_REPLACE_DIALOG));
 	/* gtk_window_set_transient_for (GTK_WINDOW(sg->dialog)
 	  , GTK_WINDOW(app->widgets.window)); */
 		
@@ -1310,13 +1310,13 @@ create_dialog(void)
 	for (i=0; NULL != glade_widgets[i].name; ++i)
 	{
 		w = &(glade_widgets[i]);
-		w->widget = glade_xml_get_widget(sg->xml, w->name);
+		w->widget = GTK_WIDGET (gtk_builder_get_object (sg->bxml, w->name));
 		if (GE_COMBO_ENTRY == w->type)
 		{
 			/* Get child of GtkComboBoxEntry */
 			w->widget = GTK_BIN(w->widget)->child;
 		}
-		gtk_widget_ref(w->widget);
+		g_object_ref(w->widget);
 		if (GE_COMBO == w->type && NULL != w->extra)
 		{
 			search_set_popdown_map(GTK_COMBO_BOX(w->widget), (AnjutaUtilStringMap *)w->extra);
@@ -1343,8 +1343,8 @@ create_dialog(void)
 
 	search_preferences_initialize_setting_treeview(sg->dialog);
 	search_preferences_init();
-	
-	glade_xml_signal_autoconnect(sg->xml);
+
+	gtk_builder_connect_signals (sg->bxml, NULL);
 	return TRUE;
 }
 
@@ -2000,6 +2000,7 @@ anjuta_search_replace_activate (gboolean replace, gboolean project)
 {
 	GtkWidget *notebook;
 	GtkWidget *search_entry;
+	GtkWidget *search_button;
 	IAnjutaDocument *doc;
 	IAnjutaEditor *te;
 
@@ -2012,6 +2013,7 @@ anjuta_search_replace_activate (gboolean replace, gboolean project)
 	reset_flags_and_search_button();
 	
 	search_entry = sr_get_gladewidget(SEARCH_STRING)->widget;
+	search_button = sr_get_gladewidget(SEARCH_BUTTON)->widget;
 	doc = ianjuta_document_manager_get_current_document(sr->docman, NULL);
 	te = (IANJUTA_IS_EDITOR (doc)) ? IANJUTA_EDITOR (doc) : NULL;
 	if (te && search_entry && sr->search.range.type != SR_SELECTION)
@@ -2072,5 +2074,12 @@ anjuta_search_replace_activate (gboolean replace, gboolean project)
 	/* Show the dialog */
 	if (search_entry)
 	gtk_widget_grab_focus (search_entry);
+
+	/* Set default button */
+	if (search_button)
+	{
+		GTK_WIDGET_SET_FLAGS (search_button, GTK_CAN_DEFAULT);
+		gtk_widget_grab_default(search_button);
+	}
 	show_dialog();
 }
