@@ -27,7 +27,7 @@
  * list of people on the anjuta Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: anjuta-view.c 3725 2008-02-28 08:49:19Z jhs $ 
+ * $Id$ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,9 +43,9 @@
 #include <glib.h>
 
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-encodings.h>
 
 #include "anjuta-view.h"
-#include "anjuta-encodings.h"
 #include "sourceview.h"
 #include "sourceview-private.h"
 #include "anjuta-marshal.h"
@@ -66,7 +66,7 @@ struct _AnjutaViewPrivate
   Sourceview* sv;
 };
 
-static void	anjuta_view_destroy		(GtkObject       *object);
+static void	anjuta_view_dispose		(GObject       *object);
 static void	anjuta_view_finalize		(GObject         *object);
 static void	anjuta_view_move_cursor		(GtkTextView     *text_view,
 						 GtkMovementStep  step,
@@ -102,15 +102,6 @@ scroll_to_cursor_real (AnjutaView *view)
 	return FALSE;
 }
 
-static void
-document_read_only_notify_handler (AnjutaDocument *document, 
-			           GParamSpec    *pspec,
-				   AnjutaView     *view)
-{
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), 
-				    !anjuta_document_get_readonly (document));
-}
-
 static void
 anjuta_view_set_property (GObject * object,
 			   guint property_id,
@@ -171,13 +162,12 @@ static void
 anjuta_view_class_init (AnjutaViewClass *klass)
 {
 	GObjectClass     *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass   *gtkobject_class = GTK_OBJECT_CLASS (klass);
 	GtkTextViewClass *textview_class = GTK_TEXT_VIEW_CLASS (klass);
 	GtkWidgetClass   *widget_class = GTK_WIDGET_CLASS (klass);
 	GtkBindingSet    *binding_set;
 	GParamSpec *anjuta_view_spec_popup;
 
-	gtkobject_class->destroy = anjuta_view_destroy;
+	object_class->dispose = anjuta_view_dispose;
 	object_class->finalize = anjuta_view_finalize;
 	object_class->set_property = anjuta_view_set_property;
 	object_class->get_property = anjuta_view_get_property;	
@@ -321,13 +311,16 @@ anjuta_view_init (AnjutaView *view)
 }
 
 static void
-anjuta_view_destroy (GtkObject *object)
+anjuta_view_dispose (GObject *object)
 {
 	AnjutaView *view;
 
 	view = ANJUTA_VIEW (object);
 	
-	(* GTK_OBJECT_CLASS (anjuta_view_parent_class)->destroy) (object);
+	if (view->priv->scroll_idle > 0)
+				g_source_remove (view->priv->scroll_idle);
+		
+	(* G_OBJECT_CLASS (anjuta_view_parent_class)->dispose) (object);
 }
 
 static void
@@ -383,20 +376,10 @@ anjuta_view_new (Sourceview *sv)
 {
 	GtkWidget *view;
 
-	g_return_val_if_fail (ANJUTA_IS_DOCUMENT (sv->priv->document), NULL);
-
 	view = GTK_WIDGET (g_object_new (ANJUTA_TYPE_VIEW, NULL));
 	
 	gtk_text_view_set_buffer (GTK_TEXT_VIEW (view),
 				  GTK_TEXT_BUFFER (sv->priv->document));
-  		
-	g_signal_connect (sv->priv->document,
-			  "notify::read-only",
-			  G_CALLBACK (document_read_only_notify_handler),
-			  view);
-
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), 
-				    !anjuta_document_get_readonly (sv->priv->document));					  
 
 	gtk_widget_show_all (view);
 
@@ -416,14 +399,16 @@ anjuta_view_cut_clipboard (AnjutaView *view)
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	g_return_if_fail (buffer != NULL);
 
+	if (!gtk_text_view_get_editable (GTK_TEXT_VIEW(view)))
+		return;
+	
 	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (view),
 					      GDK_SELECTION_CLIPBOARD);
 
 	/* FIXME: what is default editability of a buffer? */
   	gtk_text_buffer_cut_clipboard (buffer,
   				       clipboard,
-				       !anjuta_document_get_readonly (
-				       		ANJUTA_DOCUMENT (buffer)));
+				       TRUE);
   	
 	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
 				      gtk_text_buffer_get_insert (buffer),
@@ -470,8 +455,7 @@ anjuta_view_paste_clipboard (AnjutaView *view)
   	gtk_text_buffer_paste_clipboard (buffer,
 					 clipboard,
 					 NULL,
-					 !anjuta_document_get_readonly (
-						ANJUTA_DOCUMENT (buffer)));
+					 TRUE);
 
 	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
 				      gtk_text_buffer_get_insert (buffer),
@@ -494,8 +478,7 @@ anjuta_view_delete_selection (AnjutaView *view)
 	/* FIXME: what is default editability of a buffer? */
 	gtk_text_buffer_delete_selection (buffer,
 					  TRUE,
-					  !anjuta_document_get_readonly (
-						ANJUTA_DOCUMENT (buffer)));
+					  TRUE);
 						
 	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
 				      gtk_text_buffer_get_insert (buffer),
@@ -528,137 +511,6 @@ anjuta_view_scroll_to_cursor (AnjutaView *view)
 	view->priv->scroll_idle = g_idle_add ((GSourceFunc) scroll_to_cursor_real, view);
 }
 
-/* assign a unique name */
-static G_CONST_RETURN gchar *
-get_widget_name (GtkWidget *w)
-{
-	const gchar *name;	
-
-	name = gtk_widget_get_name (w);
-	g_return_val_if_fail (name != NULL, NULL);
-
-	if (strcmp (name, g_type_name (GTK_WIDGET_TYPE (w))) == 0)
-	{
-		static guint d = 0;
-		gchar *n;
-
-		n = g_strdup_printf ("%s_%u_%u", name, d, (guint) g_random_int);
-		d++;
-
-		gtk_widget_set_name (w, n);
-		g_free (n);
-
-		name = gtk_widget_get_name (w);
-	}
-
-	return name;
-}
-
-/* There is no clean way to set the cursor-color, so we are stuck
- * with the following hack: set the name of each widget and parse
- * a gtkrc string.
- */
-static void 
-modify_cursor_color (GtkWidget *textview, 
-		     GdkColor  *color)
-{
-	static const char cursor_color_rc[] =
-		"style \"svs-cc\"\n"
-		"{\n"
-			"GtkSourceView::cursor-color=\"#%04x%04x%04x\"\n"
-		"}\n"
-		"widget \"*.%s\" style : application \"svs-cc\"\n";
-
-	const gchar *name;
-	gchar *rc_temp;
-
-	name = get_widget_name (textview);
-	g_return_if_fail (name != NULL);
-
-	if (color != NULL)
-	{
-		rc_temp = g_strdup_printf (cursor_color_rc,
-					   color->red, 
-					   color->green, 
-					   color->blue,
-					   name);
-	}
-	else
-	{
-		GtkRcStyle *rc_style;
-
- 		rc_style = gtk_widget_get_modifier_style (textview);
-
-		rc_temp = g_strdup_printf (cursor_color_rc,
-					   rc_style->text [GTK_STATE_NORMAL].red,
-					   rc_style->text [GTK_STATE_NORMAL].green,
-					   rc_style->text [GTK_STATE_NORMAL].blue,
-					   name);
-	}
-
-	gtk_rc_parse_string (rc_temp);
-	gtk_widget_reset_rc_styles (textview);
-
-	g_free (rc_temp);
-}
-
-void
-anjuta_view_set_colors (AnjutaView *view,
-		       gboolean   def,
-		       GdkColor  *backgroud,
-		       GdkColor  *text,
-		       GdkColor  *selection,
-		       GdkColor  *sel_text)
-{
-
-	g_return_if_fail (ANJUTA_IS_VIEW (view));
-
-	/* just a bit of paranoia */
-	gtk_widget_ensure_style (GTK_WIDGET (view));
-
-	if (!def)
-	{
-		if (backgroud != NULL)
-			gtk_widget_modify_base (GTK_WIDGET (view), 
-						GTK_STATE_NORMAL, backgroud);
-
-		if (selection != NULL)
-		{
-			gtk_widget_modify_base (GTK_WIDGET (view), 
-						GTK_STATE_SELECTED, selection);
-			gtk_widget_modify_base (GTK_WIDGET (view), 
-						GTK_STATE_ACTIVE, selection);
-		}
-
-		if (sel_text != NULL)
-		{
-			gtk_widget_modify_text (GTK_WIDGET (view), 
-						GTK_STATE_SELECTED, sel_text);		
-			gtk_widget_modify_text (GTK_WIDGET (view), 
-						GTK_STATE_ACTIVE, sel_text);		
-		}
-
-		if (text != NULL)
-		{
-			gtk_widget_modify_text (GTK_WIDGET (view), 
-						GTK_STATE_NORMAL, text);
-			modify_cursor_color (GTK_WIDGET (view), text);
-		}
-	}
-	else
-	{
-		GtkRcStyle *rc_style;
-
-		rc_style = gtk_widget_get_modifier_style (GTK_WIDGET (view));
-
-		rc_style->color_flags [GTK_STATE_NORMAL] = 0;
-		rc_style->color_flags [GTK_STATE_SELECTED] = 0;
-		rc_style->color_flags [GTK_STATE_ACTIVE] = 0;
-
-		gtk_widget_modify_style (GTK_WIDGET (view), rc_style);
-	}
-}
-
 void
 anjuta_view_set_font (AnjutaView   *view, 
 		     gboolean     def, 
@@ -700,11 +552,11 @@ anjuta_view_expose (GtkWidget      *widget,
                    GdkEventExpose *event)
 {
 	GtkTextView *text_view;
-	AnjutaDocument *doc;
+	GtkTextBuffer *doc;
 	
 	text_view = GTK_TEXT_VIEW (widget);
 	
-	doc = ANJUTA_DOCUMENT (gtk_text_view_get_buffer (text_view));
+	doc = gtk_text_view_get_buffer (text_view);
 	
 	if ((event->window == gtk_text_view_get_window (text_view, GTK_TEXT_WINDOW_TEXT)))
 	{
@@ -752,7 +604,7 @@ anjuta_view_key_press_event		(GtkWidget *widget, GdkEventKey       *event)
       case GDK_Down:
       case GDK_Page_Up:
       case GDK_Page_Down:
-        gtk_widget_destroy (GTK_WIDGET(view->priv->sv->priv->assist_tip));
+        gtk_widget_destroy (GTK_WIDGET(assist_tip));
         break;
 		}
 	}
@@ -764,10 +616,40 @@ anjuta_view_button_press_event	(GtkWidget *widget, GdkEventButton *event)
 {
 	AnjutaView* view = ANJUTA_VIEW(widget);
 	
+  /* If we have a calltip shown - hide it */
+  AssistTip* assist_tip = view->priv->sv->priv->assist_tip;
+  AssistWindow* assist_win = view->priv->sv->priv->assist_win;
+  if (assist_win)
+  {
+    gtk_widget_destroy (GTK_WIDGET (assist_win));
+  }
+	if (assist_tip)
+	{
+    gtk_widget_destroy (GTK_WIDGET (assist_tip));
+  }
+  
 	switch(event->button)
 	{
 		case 3: /* Right Button */
 		{
+			GtkTextBuffer* buffer = GTK_TEXT_BUFFER (view->priv->sv->priv->document);
+			if (!gtk_text_buffer_get_has_selection (buffer))
+			{
+				/* Move cursor to set breakpoints at correct line (#530689) */
+				GtkTextIter iter;
+				gint buffer_x, buffer_y;
+				GtkTextWindowType type =  gtk_text_view_get_window_type (GTK_TEXT_VIEW (view),
+																																 event->window);
+				gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (view),
+																							 type,
+																							 event->x,
+																							 event->y,
+																							 &buffer_x,
+																							 &buffer_y);
+				gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (view),
+																						&iter, buffer_x, buffer_y);
+				gtk_text_buffer_place_cursor (buffer, &iter);
+			}												 
 			gtk_menu_popup (GTK_MENU (view->priv->popup), NULL, NULL, NULL, NULL, 
                   event->button, event->time);
 			return TRUE;
